==> lxqt-l10n_0.11.1.orig.tar.xz: lxqt-l10n-0.11.1/lxqt-panel/plugin-sensors/sensors_es.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="es">
<context>
    <name>LXQtSensorsConfiguration</name>
    <message>
        <source>LXQt Sensors Settings</source>
        <translation type="vanished">Opciones de Sensores de LXQt</translation>
    </message>
    <message>
        <location filename="../../../lxqtsensorsconfiguration.ui" line="14"/>
        <source>Sensors Settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../lxqtsensorsconfiguration.ui" line="30"/>
        <source>Common</source>
        <translation>Común</translation>
    </message>
    <message>
        <location filename="../../../lxqtsensorsconfiguration.ui" line="42"/>
        <source>Update interval (seconds)</source>
        <translation>Intervalo de actualización (segundos)</translation>
    </message>
    <message>
        <location filename="../../../lxqtsensorsconfiguration.ui" line="49"/>
        <source>Temperature bar width</source>
        <translation>Ancho de la barra de temperatura</translation>
    </message>
    <message>
        <location filename="../../../lxqtsensorsconfiguration.ui" line="104"/>
        <source>Temperature scale</source>
        <translation>Escala de temperatura</translation>
    </message>
    <message>
        <location filename="../../../lxqtsensorsconfiguration.ui" line="110"/>
        <source>Celsius</source>
        <translation>Celsius</translation>
    </message>
    <message>
        <location filename="../../../lxqtsensorsconfiguration.ui" line="120"/>
        <source>Fahrenheit</source>
        <translation>Fahrenheit</translation>
    </message>
    <message>
        <location filename="../../../lxqtsensorsconfiguration.ui" line="132"/>
        <source>Blink progress bars when the temperature is too high</source>
        <translation>Parpadeo en las barras de progreso cuando la temperatura es demasiado alta</translation>
    </message>
    <message>
        <location filename="../../../lxqtsensorsconfiguration.ui" line="138"/>
        <source>Warning about high temperature</source>
        <translation>Advertencia cuando la temperatura sea alta</translation>
    </message>
    <message>
        <location filename="../../../lxqtsensorsconfiguration.ui" line="152"/>
        <source>Sensors</source>
        <translation>Sensores</translation>
    </message>
    <message>
        <location filename="../../../lxqtsensorsconfiguration.ui" line="168"/>
        <source>Detected chips:</source>
        <translation>Chips detectado:</translation>
    </message>
    <message>
        <location filename="../../../lxqtsensorsconfiguration.ui" line="175"/>
        <source>Chip features:</source>
        <translation>Características del chip:</translation>
    </message>
    <message>
        <location filename="../../../lxqtsensorsconfiguration.cpp" line="195"/>
        <source>Enabled</source>
        <translation>Habilitado</translation>
    </message>
    <message>
        <location filename="../../../lxqtsensorsconfiguration.cpp" line="195"/>
        <source>Label</source>
        <translation>Etiqueta</translation>
    </message>
    <message>
        <location filename="../../../lxqtsensorsconfiguration.cpp" line="195"/>
        <source>Color</source>
        <translation>Color</translation>
    </message>
</context>
</TS>

==> lxqt-l10n_0.13.0.orig.tar.xz: lxqt-l10n-0.13.0/lxqt-panel/plugin-sensors/sensors_es.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="es">
<context>
    <name>LXQtSensorsConfiguration</name>
    <message>
        <source>LXQt Sensors Settings</source>
        <translation type="vanished">Opciones de Sensores de LXQt</translation>
    </message>
    <message>
        <location filename="../../../lxqtsensorsconfiguration.ui" line="14"/>
        <source>Sensors Settings</source>
        <translation>Configuración de sensores</translation>
    </message>
    <message>
        <location filename="../../../lxqtsensorsconfiguration.ui" line="30"/>
        <source>Common</source>
        <translation>Común</translation>
    </message>
    <message>
        <location filename="../../../lxqtsensorsconfiguration.ui" line="42"/>
        <source>Update interval (seconds)</source>
        <translation>Intervalo de actualización (segundos)</translation>
    </message>
    <message>
        <location filename="../../../lxqtsensorsconfiguration.ui" line="49"/>
        <source>Temperature bar width</source>
        <translation>Ancho de la barra de temperatura</translation>
    </message>
    <message>
        <location filename="../../../lxqtsensorsconfiguration.ui" line="104"/>
        <source>Temperature scale</source>
        <translation>Escala de temperatura</translation>
    </message>
    <message>
        <location filename="../../../lxqtsensorsconfiguration.ui" line="110"/>
        <source>Celsius</source>
        <translation>Celsius</translation>
    </message>
    <message>
        <location filename="../../../lxqtsensorsconfiguration.ui" line="120"/>
        <source>Fahrenheit</source>
        <translation>Fahrenheit</translation>
    </message>
    <message>
        <location filename="../../../lxqtsensorsconfiguration.ui" line="132"/>
        <source>Blink progress bars when the temperature is too high</source>
        <translation>Hacer titilar las barras cuando la temperatura sea demasiado alta</translation>
    </message>
    <message>
        <location filename="../../../lxqtsensorsconfiguration.ui" line="138"/>
        <source>Warning about high temperature</source>
        <translation>Avisar cuando la temperatura sea alta</translation>
    </message>
    <message>
        <location filename="../../../lxqtsensorsconfiguration.ui" line="152"/>
        <source>Sensors</source>
        <translation>Sensores</translation>
    </message>
    <message>
        <location filename="../../../lxqtsensorsconfiguration.ui" line="168"/>
        <source>Detected chips:</source>
        <translation>Chips detectados:</translation>
    </message>
    <message>
        <location filename="../../../lxqtsensorsconfiguration.ui" line="175"/>
        <source>Chip features:</source>
        <translation>Características del chip:</translation>
    </message>
    <message>
        <location filename="../../../lxqtsensorsconfiguration.cpp" line="195"/>
        <source>Enabled</source>
        <translation>Habilitado</translation>
    </message>
    <message>
        <location filename="../../../lxqtsensorsconfiguration.cpp" line="195"/>
        <source>Label</source>
        <translation>Etiqueta</translation>
    </message>
    <message>
        <location filename="../../../lxqtsensorsconfiguration.cpp" line="195"/>
        <source>Color</source>
        <translation>Color</translation>
    </message>
</context>
</TS>
